Type: Package
Package: CSHShydRology
Title: Canadian Hydrological Analyses
Version: 1.5.0
Date: 2026-04-20
Authors@R: c(person("Kevin", "Shook", 
              email = "kshook@kshook.ca", 
              role = c("cre", "aut")),
             person("Paul", "Whitfield", 
                email = "paul.h.whitfield@gmail.com", 
                role = c("aut")),
             person("Robert", "Chlumsky",
                email = "rchlumsk@uwaterloo.ca", 
                role = c("aut")),
             person("Daniel", "Moore", 
                email = "dan.moore@ubc.ca", 
                role = c("aut")),
             person("Martin", "Durocher", 
                role = c("aut")),
             person("Matthew", "Lemieux", 
                role = c("ctb")),
             person("Jason", "Chiang", 
                role = c("ctb")),
             person("Joel", "Trubilowicz", 
                role = c("ctb")),
             person("SJ", "Kim", 
                role = c("ctb")),
             person("Billy", "Browning", 
               role = c("aut"))
             )                
Author: Kevin Shook [cre, aut],
  Paul Whitfield [aut],
  Robert Chlumsky [aut],
  Daniel Moore [aut],
  Martin Durocher [aut],
  Matthew Lemieux [ctb],
  Jason Chiang [ctb],
  Joel Trubilowicz [ctb],
  SJ Kim [ctb],
  Billy Browning [aut]
Maintainer: Kevin Shook <kshook@kshook.ca>
Description: A collection of user-submitted functions to aid in the analysis of hydrological data, particularly for users in Canada. The functions focus on the use of Canadian data sets, and are suited to Canadian hydrology, such as the important cold region hydrological processes and will work with Canadian hydrological models. The functions are grouped into several themes, currently including Statistical hydrology, Basic data manipulations, Visualization, and Spatial hydrology. Functions developed by the Floodnet project are also included. CSHShydRology has been developed with the assistance of the Canadian Society for Hydrological Sciences (CSHS) which is an affiliated society of the Canadian Water Resources Association (CWRA). As of version 1.2.6, functions now fail gracefully when attempting to download data from a url which is unavailable.
License: AGPL-3
URL: https://github.com/CSHS-hydRology/CSHShydRology
Depends: R (>= 4.1.0)
Imports: fields, lubridate, plotrix, timeDate, stringr, ggplot2,
        ggspatial, stats, dplyr, httr2, terra, tidyterra, tidyhydat,
        whitebox, datasets, circular, MGBT, outliers, TeachingDemos,
        Kendall
Suggests: knitr, testthat, rmarkdown, readr
VignetteBuilder: knitr
LazyData: true
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-20 20:50:09 UTC; kevin
Repository: CRAN
Date/Publication: 2026-04-20 21:50:03 UTC
Built: R 4.6.0; ; 2026-04-25 13:38:54 UTC; unix
