# Generated by roxygen2: do not edit by hand

S3method(ch_rfa_distseason,data.frame)
S3method(ch_rfa_distseason,formula)
S3method(ch_rfa_distseason,matrix)
S3method(ch_rfa_distseason,numeric)
S3method(ch_rfa_extractamax,default)
S3method(ch_rfa_extractamax,formula)
S3method(ch_rfa_seasonstat,data.frame)
S3method(ch_rfa_seasonstat,default)
S3method(ch_rfa_seasonstat,formula)
export(ch_axis_doy)
export(ch_binned_MannWhitney)
export(ch_booth_plot)
export(ch_catchment_hyps)
export(ch_checkcatchment)
export(ch_checkchannels)
export(ch_circ_mean_reg)
export(ch_circular_colors)
export(ch_clear_wd)
export(ch_col_gradient)
export(ch_col_transparent)
export(ch_color_gradient)
export(ch_contours)
export(ch_create_wd)
export(ch_cut_block)
export(ch_date_subset)
export(ch_decades_plot)
export(ch_doys)
export(ch_fdcurve)
export(ch_ffa_screen_plot)
export(ch_flow_raster)
export(ch_flow_raster_qa)
export(ch_flow_raster_trend)
export(ch_get_ECDE_metadata)
export(ch_get_peaks)
export(ch_get_url_data)
export(ch_get_wscstation)
export(ch_gg_hydrographs)
export(ch_high_Grubbs_test)
export(ch_model_hydrograph)
export(ch_polar_plot)
export(ch_polar_plot_peaks)
export(ch_polar_plot_prep)
export(ch_qa_hydrograph)
export(ch_read_AHCCD_daily)
export(ch_read_AHCCD_monthly)
export(ch_read_ECDE_flows)
export(ch_regime_plot)
export(ch_rfa_distseason)
export(ch_rfa_extractamax)
export(ch_rfa_julianplot)
export(ch_rfa_seasonstat)
export(ch_safe_GET)
export(ch_sh_get_amax)
export(ch_slice)
export(ch_stack_EC)
export(ch_sub_set_Years)
export(ch_test_url_file)
export(ch_tidyhydat_ECDE)
export(ch_tidyhydat_ECDE_meta)
export(ch_tr_sign)
export(ch_tr_signif)
export(ch_volcano_pourpoints)
export(ch_volcano_raster)
export(ch_wbt_catchment)
export(ch_wbt_catchment_onestep)
export(ch_wbt_channels)
export(ch_wbt_check_whitebox)
export(ch_wbt_filenames)
export(ch_wbt_flow_accumulation)
export(ch_wbt_flow_direction)
export(ch_wbt_pourpoints)
export(ch_wbt_removesinks)
export(ch_wtr_yr)
import(TeachingDemos)
import(circular)
import(dplyr)
import(ggplot2)
import(tidyhydat)
importFrom(Kendall,MannKendall)
importFrom(MGBT,MGBT)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(fields,image.plot)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_bw)
importFrom(ggspatial,annotation_north_arrow)
importFrom(ggspatial,annotation_scale)
importFrom(ggspatial,north_arrow_fancy_orienteering)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,hsv)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,frame)
importFrom(graphics,grconvertX)
importFrom(graphics,grconvertY)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(grid,unit)
importFrom(httr2,req_perform)
importFrom(httr2,request)
importFrom(lubridate,date)
importFrom(lubridate,day)
importFrom(lubridate,month)
importFrom(lubridate,year)
importFrom(outliers,grubbs.test)
importFrom(plotrix,radial.grid)
importFrom(plotrix,radial.plot)
importFrom(stats,approx)
importFrom(stats,dist)
importFrom(stats,get_all_vars)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,step)
importFrom(stats,wilcox.test)
importFrom(stringr,fixed)
importFrom(stringr,str_detect)
importFrom(stringr,str_split_fixed)
importFrom(stringr,str_to_lower)
importFrom(terra,as.contour)
importFrom(terra,crs)
importFrom(terra,hist)
importFrom(terra,mask)
importFrom(terra,minmax)
importFrom(terra,plot)
importFrom(terra,quantile)
importFrom(terra,rast)
importFrom(terra,values)
importFrom(tidyhydat,hy_agency_list)
importFrom(tidyhydat,hy_daily)
importFrom(tidyhydat,hy_datum_list)
importFrom(tidyhydat,hy_reg_office_list)
importFrom(tidyhydat,hy_sed_daily_loads)
importFrom(tidyhydat,hy_stations)
importFrom(tidyhydat,hy_stn_data_coll)
importFrom(tidyhydat,hy_stn_data_range)
importFrom(tidyhydat,hy_stn_regulation)
importFrom(tidyhydat,hy_version)
importFrom(timeDate,as.timeDate)
importFrom(timeDate,dayOfYear)
importFrom(utils,data)
importFrom(utils,read.csv)
importFrom(utils,read.fwf)
importFrom(utils,read.table)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,write.csv)
importFrom(whitebox,check_whitebox_binary)
importFrom(whitebox,wbt_breach_depressions)
importFrom(whitebox,wbt_breach_depressions_least_cost)
importFrom(whitebox,wbt_d8_flow_accumulation)
importFrom(whitebox,wbt_d8_pointer)
importFrom(whitebox,wbt_extract_streams)
importFrom(whitebox,wbt_fill_depressions)
importFrom(whitebox,wbt_fill_depressions_planchon_and_darboux)
importFrom(whitebox,wbt_fill_depressions_wang_and_liu)
importFrom(whitebox,wbt_fill_single_cell_pits)
importFrom(whitebox,wbt_init)
importFrom(whitebox,wbt_raster_streams_to_vector)
importFrom(whitebox,wbt_raster_to_vector_polygons)
importFrom(whitebox,wbt_snap_pour_points)
importFrom(whitebox,wbt_watershed)
