#' Statistical analysis functions
#' @name StatisticalHydrology-functions
#' @description These functions perform statistical analyses
#' \describe{
#'  \item{ch_binned_MannWhitney}{ Compares two time periods of data using Mann-Whitney test}
#'  \item{ch_fdcurve}{Finds flow exceedence probabilities}
#'  \item{ch_get_peaks}{Finds peak flows over a specified threshold}
#' }
NULL