#' Visualization functions
#' @name Visualization-functions
#' @description These functions are primarily intended for graphing, although
#' some analyses may also be done.
#' \describe{
#'  \item{ch_booth_plot}{Plot of peaks over a threshold}
#'  \item{ch_ffa_screen_plot}{FFA screening plot}
#'  \item{ch_flow_raster}{Raster plot of streamflows}
#'  \item{ch_flow_raster_qa}{Raster plot of streamflows with WSC quality flags}
#'  \item{ch_gg_hydrographs}{ggplot2 hydrographs of WSC flows}
#'  \item{ch_model_hydrograph}{Plots hydrographs and/or precipitation}
#'  \item{ch_polar_plot}{Polar plot of daily streamflows}
#'  \item{ch_qa_hydrograph}{Plots a hydrograph with the data quality symbols}
#'  \item{ch_regime_plot}{Plots the regime of daily streamflows}
#' }
NULL