#####################################################################
#' Streamflow data
#'
#' Daily river discharge for the station 01AD002 on
#' St. John River at Fort Kent, New Brunswick.
#' Data ranges from 1926 to 2014, for basin area of 14700 sq km.
#' 
#' @author Martin Durocher
#' @source \url{https://wateroffice.ec.gc.ca/}
#####################################################################
"CAN01AD002"

#####################################################################
#' Annual maxima from sites in the Atlantic region of Canada
#'
#' Contains the annual maxima of 45 hydrometric stations found in the
#' region '01' of Water Survey of Canada.
#' In additional to the annual maxima, the output list includes catchment
#' descriptors (longitude, latitude, basin area, mean annual precipitation)
#' and the geographical distance between each station.
#'
#' @author Martin Durocher
#' @source \url{https://wateroffice.ec.gc.ca/}
#####################################################################
"flowAtlantic"



