#' Basic data manipulation functions
#' @name Basic_data_manipulation_functions
#' @description These functions read in or convert values among formats
#' \describe{
#'  \item{ch_read_ECDE_flows}{Reads a file of WSC daily flows from ECDataExplorer}
#'  \item{ch_get_ECDE_metadata}{Reads station meta data from ECDataExplorer}
#'  \item{ch_get_wscstation}{Reads station information from a data file produced by ECDE}
#'  \item{ch_read_AHCCD_daily}{Reads file of daily AHCCD values}
#'  \item{ch_read_AHCCD_monthly}{Reads file of monthly AHCCD values}
#'  \item{ch_tidyhydat_ECDE}{Reads flows using \pkg{tidyhydat} and converts to ECDE format}
#'  \item{ch_tidyhydat_ECDE_meta}{Reads station meta data using \pkg{tidyhydat} and converts to ECDE-like format}
#' }
NULL